# practice-problem1
The following packages exist to practice object-oriented programming, collaborative development, and generalized programming. This package will allow you to practice using Docstring, unit testing, and package design. This package basically just contains a Python class to compute arithmetic operations.  You will use this class to practice your Python skills. The tasks you need to solve will be given to you by the package manager.


# How to install
1. Run `pip install -U https://github.com/joonyeobjeon/practice-problem1.git`
2. Run cd practice-problem1
3. (Optional) If you do not have poetry installed, run `make poetry-install`
4. Run `make install`

# How to run in cli
Simply run `make cli`


You can use the `practice` package now.